#include "fenetre_rs232.h"


///////////////////////////////////////////
// Creation de l'objet
RS232::RS232(QWidget *parent) : QDialog(parent)
{
        ui.setupUi(this);

  // on charge les donnees sur le disque dur
  charger();
}



///////////////////////////////////////////
// Fermer la fenetre et enregistrer
void RS232::on_pushButton_rs232_clicked()
{
  // on ferme la fenetre
  this->hide();

  // on sauve les resultats sur le disque dur
  sauver();

} 



///////////////////////////////////////////
// Sauver les donnees sur le disque dur
void RS232::sauver(void)
{
  // recuperation des donnees
  QString value1 = ui.lineEdit->text(); 
  int value2 = ui.comboBox->currentIndex(); 

  QFile file;
  file.setFileName("config/config_rs232.ini");
  if( file.exists() )
    file.remove();
  file.open(QIODevice::Append | QIODevice::Text );
  QTextStream out(&file);
  out << value1 << endl;    
  out << value2; 
  file.close();

} 


///////////////////////////////////////////
// Charger les donnees sur le disque dur
void RS232::charger(void)
{
  QFile file;
  file.setFileName("config/config_rs232.ini");
  if( !file.exists() )
    return;      

  // creation des variables
  QString value1 = "COM1"; 
  int value2 = 0; 


  file.open(QIODevice::ReadOnly | QIODevice::Text );
  QTextStream in(&file);
  QString line;
  line = in.readLine(); 
  value1 = line;
  line = in.readLine(); 
  value2 = line.toInt();
  file.close();

  ui.lineEdit->setText(value1); 
  ui.comboBox->setCurrentIndex(value2); 

} 


///////////////////////////////////////////
// Connexion a l'appareil
int RS232::connexion(QextSerialPort *port)
{
  int retour = 0;

  // recuperation des donnees du port RS232
  QString nomport = ui.lineEdit->text();
  QString baudrate = ui.comboBox->currentText();

  PortSettings settings;

  if(baudrate == "300")
    settings.BaudRate = BAUD300;    // 300 bauds
  else if(baudrate == "600")
    settings.BaudRate = BAUD600;    // 600 bauds
  else if(baudrate == "1200")
    settings.BaudRate = BAUD1200;    // 1200 bauds
  else if(baudrate == "2400")
    settings.BaudRate = BAUD2400;    // 2400 bauds
  else if(baudrate == "4800")
    settings.BaudRate = BAUD4800;    // 4800 bauds
  else if(baudrate == "9600")
    settings.BaudRate = BAUD9600;    // 9600 bauds
  else if(baudrate == "19200")
    settings.BaudRate = BAUD19200;    // 19200 bauds
  else if(baudrate == "38400")
    settings.BaudRate = BAUD38400;    // 19200 bauds

  settings.Parity = PAR_NONE;    // pas de parite

  settings.DataBits = DATA_8;   // 8 bits de donnees

  settings.StopBits = STOP_1;    // bit de stop 1.0

  settings.Timeout_Millisec = 500;    // delai de timeout fixe a 500ms
 
  // si la connexion existe deja, on la ferme
  if(port != NULL)
  {
	   port->close(); // on ferme le port
       delete port;
       port = NULL;
  }

  // connexion
  if(port == NULL)
  {
       port = new QextSerialPort(nomport,settings); 
  }

  // ouverture du port
  port->open(QIODevice::ReadWrite); // on ouvre le port

  // on regarde si le port est bien ouvert
  if(port->isOpen() != 1)
  {
	port->close();
    delete port;
    port = NULL;

    retour = -1;
  }
  else // le port est bien ouvert
  {
    // on remet tous les parametres pour etre sur qu'ils ont bien ete pris en compte
       if(baudrate == "300")
         port->setBaudRate(BAUD300);    // 300 bauds
       else if(baudrate == "600")
         port->setBaudRate(BAUD600);    // 600 bauds
       else if(baudrate == "1200")
         port->setBaudRate(BAUD1200);    // 1200 bauds
       else if(baudrate == "2400")
         port->setBaudRate(BAUD2400);    // 2400 bauds
       else if(baudrate == "4800")
         port->setBaudRate(BAUD4800);    // 4800 bauds
       else if(baudrate == "9600")
         port->setBaudRate(BAUD9600);    // 9600 bauds
       else if(baudrate == "19200")
         port->setBaudRate(BAUD19200);    // 19200 bauds
       else if(baudrate == "38400")
         port->setBaudRate(BAUD38400);    // 38400 bauds

       port->setFlowControl(FLOW_OFF); // pas de controle de flux

       port->setParity(PAR_NONE);    // pas de parite

       port->setDataBits(DATA_8);   // 8 bits de donnees

       port->setStopBits(STOP_1);    // bit de stop 1.0

//       port->setTimeout( 500 );    // reglage du timeout

       retour = (int)port;
  }


  return retour;
} 

