/////////////////////////////////////////////
// TPG300 Programm number
QString TPG300::programmnumber(void)
{
  QString valeur_retour = "-1"; // par defaut, on met a -1

  if(port == NULL) // Il y a un probleme
    return valeur_retour;        

  // envoi de PNR
  send_rs232("PNR");

  // reception de ACK (06) ou NAK (15)
  QString message = receive_rs232();
  if(message.contains("\x06") == FALSE )
    return "-1";

  // envoi de <ENQ>
  send_rs232("\x05");

  // reception de la valeur
  QString valeur = receive_rs232();

  // on retire <CR> et <LF>
  valeur = valeur.replace("\x0D", ""); // on supprime les caracteres de fin
  valeur = valeur.replace("\x0A", "");

  return valeur; 
}


/////////////////////////////////////////////
// TPG300 Code lock
QString TPG300::codelock(void)
{
  QString valeur_retour = "-1"; // par defaut, on met a -1

  if(port == NULL) // Il y a un probleme
    return valeur_retour;        

  // envoi de COD
  send_rs232("COD");

  // reception de ACK (06) ou NAK (15)
  QString message = receive_rs232();
  if(message.contains("\x06") == FALSE )
    return "-1";

  // envoi de <ENQ>
  send_rs232("\x05");

  // reception de la valeur
  QString valeur = receive_rs232();

  // on retire <CR> et <LF>
  valeur = valeur.replace("\x0D", ""); // on supprime les caracteres de fin
  valeur = valeur.replace("\x0A", "");

  return valeur; 
}

/////////////////////////////////////////////
// TPG300 Error Status
QString TPG300::errorstatus(void)
{
  QString valeur_retour = "-1"; // par defaut, on met a -1

  if(port == NULL) // Il y a un probleme
    return valeur_retour;        

  // envoi de ERR
  send_rs232("ERR");

  // reception de ACK (06) ou NAK (15)
  QString message = receive_rs232();
  if(message.contains("\x06") == FALSE )
    return "-1";

  // envoi de <ENQ>
  send_rs232("\x05");

  // reception de la valeur
  QString valeur = receive_rs232();

  // on retire <CR> et <LF>
  valeur = valeur.replace("\x0D", ""); // on supprime les caracteres de fin
  valeur = valeur.replace("\x0A", "");

  if(valeur == "0000")
    valeur = "No error";
  else if(valeur == "1000")
    valeur = "TPG error (see display on the front panel)";
  else if(valeur == "0100")
    valeur = "Hardware not installed";
  else if(valeur == "0010")
    valeur = "Invalid parameter";
  else if(valeur == "0001")
    valeur = "Syntax error";

  return valeur; 
}


/////////////////////////////////////////////
// TPG300 Display Unit
QString TPG300::displayunit(void)
{
  QString valeur_retour = "-1"; // par defaut, on met a -1

  if(port == NULL) // Il y a un probleme
    return valeur_retour;        

  // envoi de UNI
  send_rs232("UNI");

  // reception de ACK (06) ou NAK (15)
  QString message = receive_rs232();
  if(message.contains("\x06") == FALSE )
    return "-1";

  // envoi de <ENQ>
  send_rs232("\x05");

  // reception de la valeur
  QString valeur = receive_rs232();

  // on retire <CR> et <LF>
  valeur = valeur.replace("\x0D", ""); // on supprime les caracteres de fin
  valeur = valeur.replace("\x0A", "");

  if(valeur == "1")
    valeur = "mbar";
  else if(valeur == "2")
    valeur = "Torr";
  else if(valeur == "3")
    valeur = "Pa";

  return valeur; 
}


/////////////////////////////////////////////
// TPG300 underrange control
QString TPG300::underrangecontrol(void)
{
  QString valeur_retour = "-1"; // par defaut, on met a -1

  if(port == NULL) // Il y a un probleme
    return valeur_retour;        

  // envoi de UNI
  send_rs232("UNI");

  // reception de ACK (06) ou NAK (15)
  QString message = receive_rs232();
  if(message.contains("\x06") == FALSE )
    return "-1";

  // envoi de <ENQ>
  send_rs232("\x05");

  // reception de la valeur
  QString valeur = receive_rs232();

  // on retire <CR> et <LF>
  valeur = valeur.replace("\x0D", ""); // on supprime les caracteres de fin
  valeur = valeur.replace("\x0A", "");

  if(valeur == "0")
    valeur = "Off";
  else if(valeur == "1")
    valeur = "On";

  return valeur; 
}

/////////////////////////////////////////////
// TPG300 Set Point
QString TPG300::setpoint(QString identifiant)
{
  QString valeur_retour = "-1"; // par defaut, on met a -1

  if(port == NULL) // Il y a un probleme
    return valeur_retour;        

  // envoi de SP
  send_rs232("SP" + identifiant);

  // reception de ACK (06) ou NAK (15)
  QString message = receive_rs232();
  if(message.contains("\x06") == FALSE )
    return "-1";

  // envoi de <ENQ>
  send_rs232("\x05");

  // reception de la valeur
  QString valeur = receive_rs232();

  // on retire <CR> et <LF>
  valeur = valeur.replace("\x0D", ""); // on supprime les caracteres de fin
  valeur = valeur.replace("\x0A", "");

  // on cherche les virgules
  int virgule1 = valeur.indexOf(",", 0);
  int virgule2 = valeur.indexOf(",", virgule1+1);



  QString phrase;
  phrase = "lower threshold : " +   valeur.mid(0, virgule1) + " - upper threshold : " + valeur.mid(virgule1+1, virgule2-virgule1-1)  + " - Switching function assignment : " + valeur.mid(virgule2+1, 1);



  return phrase; 
}

/////////////////////////////////////////////
// TPG300 Switching function status
QString TPG300::setpointswitching(void)
{
  QString valeur_retour = "-1"; // par defaut, on met a -1

  if(port == NULL) // Il y a un probleme
    return valeur_retour;        

  // envoi de SPS
  send_rs232("SPS");

  // reception de ACK (06) ou NAK (15)
  QString message = receive_rs232();
  if(message.contains("\x06") == FALSE )
    return "-1";

  // envoi de <ENQ>
  send_rs232("\x05");

  // reception de la valeur
  QString valeur = receive_rs232();

  // on retire <CR> et <LF>
  valeur = valeur.replace("\x0D", ""); // on supprime les caracteres de fin
  valeur = valeur.replace("\x0A", "");

  // on cherche les etats
  QString etat1;
  QString etat2;
  QString etat3;
  QString etat4;
  QString etat5;
  QString etat6;
  if(QString::QString(valeur.at(0)) == "0")
    etat1 = "off";
  else if(QString::QString(valeur.at(0)) == "1")
    etat1 = "on";
  if(QString::QString(valeur.at(2)) == "0")
    etat2 = "off";
  else if(QString::QString(valeur.at(2)) == "1")
    etat2 = "on";
  if(QString::QString(valeur.at(4)) == "0")
    etat3 = "off";
  else if(QString::QString(valeur.at(4)) == "1")
    etat3 = "on";
  if(QString::QString(valeur.at(6)) == "0")
    etat4 = "off";
  else if(QString::QString(valeur.at(6)) == "1")
    etat4 = "on";
  if(QString::QString(valeur.at(8)) == "0")
    etat5 = "off";
  else if(QString::QString(valeur.at(8)) == "1")
    etat5 = "on";
  if(QString::QString(valeur.at(10)) == "0")
    etat6 = "off";
  else if(QString::QString(valeur.at(10)) == "1")
    etat6 = "on";

  QString phrase;
  phrase = "Switching function 1 : " + etat1 + " - Switching function 2 : " + etat2 + " - Switching function 3 : " + etat3 + " - Switching function 4 : " + etat4 + " - Switching function A : " + etat5 + " - Switching function B : " + etat6;

  return phrase; 
}


/////////////////////////////////////////////
// TPG300 Sensor On/Off
QString TPG300::sensoronoff(void)
{
  QString valeur_retour = "-1"; // par defaut, on met a -1

  if(port == NULL) // Il y a un probleme
    return valeur_retour;        

  // envoi de SEN
  send_rs232("SEN");

  // reception de ACK (06) ou NAK (15)
  QString message = receive_rs232();
  if(message.contains("\x06") == FALSE )
    return "-1";

  // envoi de <ENQ>
  send_rs232("\x05");

  // reception de la valeur
  QString valeur = receive_rs232();

  // on retire <CR> et <LF>
  valeur = valeur.replace("\x0D", ""); // on supprime les caracteres de fin
  valeur = valeur.replace("\x0A", "");

  // on cherche les etats
  QString etat1;
  QString etat2;
  QString etat3;
  QString etat4;

  if(QString::QString(valeur.at(0)) == "0")
    etat1 = "no measuring channel";
  else if(QString::QString(valeur.at(0)) == "1")
    etat1 = "off";
  else if(QString::QString(valeur.at(0)) == "2")
    etat1 = "automatic";
  else if(QString::QString(valeur.at(0)) == "3")
    etat1 = "on";

  if(QString::QString(valeur.at(2)) == "0")
    etat2 = "no measuring channel";
  else if(QString::QString(valeur.at(2)) == "1")
    etat2 = "off";
  else if(QString::QString(valeur.at(2)) == "2")
    etat2 = "automatic";
  else if(QString::QString(valeur.at(2)) == "3")
    etat2 = "on";

  if(QString::QString(valeur.at(4)) == "0")
    etat3 = "no measuring channel";
  else if(QString::QString(valeur.at(4)) == "1")
    etat3 = "off";
  else if(QString::QString(valeur.at(4)) == "2")
    etat3 = "automatic";
  else if(QString::QString(valeur.at(4)) == "3")
    etat3 = "on";

  if(QString::QString(valeur.at(6)) == "0")
    etat4 = "no measuring channel";
  else if(QString::QString(valeur.at(6)) == "1")
    etat4 = "off";
  else if(QString::QString(valeur.at(6)) == "2")
    etat4 = "automatic";
  else if(QString::QString(valeur.at(6)) == "3")
    etat4 = "on";


  QString phrase;
  phrase = "Measuring circuit A1 : " + etat1 + " - Measuring circuit A2 : " + etat2 + " - Measuring circuit B1 : " + etat3 + " - Measuring circuit B2 : " + etat4;

  return phrase; 
}


/////////////////////////////////////////////
// TPG300 Filter Time
QString TPG300::filtertime(void)
{
  QString valeur_retour = "-1"; // par defaut, on met a -1

  if(port == NULL) // Il y a un probleme
    return valeur_retour;        

  // envoi de FIL
  send_rs232("FIL");

  // reception de ACK (06) ou NAK (15)
  QString message = receive_rs232();
  if(message.contains("\x06") == FALSE )
    return "-1";

  // envoi de <ENQ>
  send_rs232("\x05");

  // reception de la valeur
  QString valeur = receive_rs232();

  // on retire <CR> et <LF>
  valeur = valeur.replace("\x0D", ""); // on supprime les caracteres de fin
  valeur = valeur.replace("\x0A", "");

  // on cherche les etats
  QString etat1;
  QString etat2;
  QString etat3;
  QString etat4;

  if(QString::QString(valeur.at(0)) == "1")
    etat1 = "fast";
  else if(QString::QString(valeur.at(0)) == "2")
    etat1 = "medium";
  else if(QString::QString(valeur.at(0)) == "3")
    etat1 = "slow";

  if(QString::QString(valeur.at(2)) == "1")
    etat2 = "fast";
  else if(QString::QString(valeur.at(2)) == "2")
    etat2 = "medium";
  else if(QString::QString(valeur.at(2)) == "3")
    etat2 = "slow";

  if(QString::QString(valeur.at(4)) == "1")
    etat3 = "fast";
  else if(QString::QString(valeur.at(4)) == "2")
    etat3 = "medium";
  else if(QString::QString(valeur.at(4)) == "3")
    etat3 = "slow";

  if(QString::QString(valeur.at(6)) == "1")
    etat4 = "fast";
  else if(QString::QString(valeur.at(6)) == "2")
    etat4 = "medium";
  else if(QString::QString(valeur.at(6)) == "3")
    etat4 = "slow";


  QString phrase;
  phrase = "Measuring circuit A1 : " + etat1 + " - Measuring circuit A2 : " + etat2 + " - Measuring circuit B1 : " + etat3 + " - Measuring circuit B2 : " + etat4;

  return phrase; 
}


/////////////////////////////////////////////
// TPG300 Slot ID's
QString TPG300::slotids(void)
{
  QString valeur_retour = "-1"; // par defaut, on met a -1

  if(port == NULL) // Il y a un probleme
    return valeur_retour;        

  // envoi de TID
  send_rs232("TID");

  // reception de ACK (06) ou NAK (15)
  QString message = receive_rs232();
  if(message.contains("\x06") == FALSE )
    return "-1";

  // envoi de <ENQ>
  send_rs232("\x05");

  // reception de la valeur
  QString valeur = receive_rs232();

  // on retire <CR> et <LF>
  valeur = valeur.replace("\x0D", ""); // on supprime les caracteres de fin
  valeur = valeur.replace("\x0A", "");

  // on cherche les virgules
  int virgule1 = valeur.indexOf(",", 0);
  int virgule2 = valeur.indexOf(",", virgule1+1);

  // on cherche les etats
  QString etat1 = valeur.mid(0, virgule1);
  QString etat2 = valeur.mid(virgule1+1, virgule2-virgule1-1);
  QString etat3 = valeur.mid(virgule2+1);

  QString phrase;
  phrase = "Identification slot A : " + etat1 + " - Identification slot B : " + etat2 + " - Identification slot C : " + etat3;

  return phrase; 
}


/////////////////////////////////////////////
// TPG300 Get Press
QString TPG300::getpress(QString identifiant)
{
  QString valeur_retour = "-1"; // par defaut, on met a -1

  if(port == NULL) // Il y a un probleme
    return valeur_retour;        

  // envoi de TID
  send_rs232("P" + identifiant);

  // reception de ACK (06) ou NAK (15)
  QString message = receive_rs232();
  if(message.contains("\x06") == FALSE )
    return "-1";

  // envoi de <ENQ>
  send_rs232("\x05");

  // reception de la valeur
  QString valeur = receive_rs232();

  // on retire <CR> et <LF>
  valeur = valeur.replace("\x0D", ""); // on supprime les caracteres de fin
  valeur = valeur.replace("\x0A", "");

  // on cherche les etats
  QString status;
  status = QString::QString(valeur.at(0));
  QString pression = valeur.mid(2);

  QString reponse;
  if(status == "0") // Measurement data okay
    reponse = pression;
  else if(status == "1")
    reponse = "Underrange";
  else if(status == "2")
    reponse = "Overrange";
  else if(status == "3")
    reponse = "Measuring circuit error";
  else if(status == "4")
    reponse = "Measuring circuit switched off";
  else if(status == "5")
    reponse = "No hardware";

  return reponse;
 
}

/////////////////////////////////////////////
// TPG261 Pressure Measurement
QString TPG300::pressuremeasurement(QString identifiant)
{
  QString valeur_retour = "-1"; // par defaut, on met a -1

  if(port == NULL) // Il y a un probleme
    return valeur_retour;        

  // envoi de TID
  send_rs232("PR" + identifiant);

  // reception de ACK (06) ou NAK (15)
  QString message = receive_rs232();
  if(message.contains("\x06") == FALSE )
    return "-1";

  // envoi de <ENQ>
  send_rs232("\x05");

  // reception de la valeur
  QString valeur = receive_rs232();

  // on retire <CR> et <LF>
  valeur = valeur.replace("\x0D", ""); // on supprime les caracteres de fin
  valeur = valeur.replace("\x0A", "");

  // on cherche les etats
  QString status;
  status = QString::QString(valeur.at(0));
  QString pression = valeur.mid(2);

  QString reponse;
  if(status == "0") // Measurement data okay
    reponse = pression;
  else if(status == "1")
    reponse = "Underrange";
  else if(status == "2")
    reponse = "Overrange";
  else if(status == "3")
    reponse = "Sensor error";
  else if(status == "4")
    reponse = "Sensor off";
  else if(status == "5")
    reponse = "No sensor";
  else if(status == "6")
    reponse = "Identification error";


  return reponse;
 
}


/////////////////////////////////////////////
// TPG261 Slot ID's
QString TPG300::gaugeidentification(void)
{
  QString valeur_retour = "-1"; // par defaut, on met a -1

  if(port == NULL) // Il y a un probleme
    return valeur_retour;        

  // envoi de TID
  send_rs232("TID");

  // reception de ACK (06) ou NAK (15)
  QString message = receive_rs232();
  if(message.contains("\x06") == FALSE )
    return "-1";

  // envoi de <ENQ>
  send_rs232("\x05");

  // reception de la valeur
  QString valeur = receive_rs232();

  // on retire <CR> et <LF>
  valeur = valeur.replace("\x0D", ""); // on supprime les caracteres de fin
  valeur = valeur.replace("\x0A", "");

  // on cherche la virgule
  int virgule = valeur.indexOf(",", 0);

  // on cherche les etats
  QString etat1 = valeur.mid(0, virgule);
  QString etat2 = valeur.mid(virgule+1);

  if(etat1 == "TPR")
    etat1 = "TPR (Pirani Gauge or Pirani Capacitive gauge)";
  else if(etat1 == "IKR9")
    etat1 = "IKR9 (Cold Cathode Gauge 10-9)";
  else if(etat1 == "IKR11")
    etat1 = "IKR11 (Cold Cathode Gauge 10-11)";
  else if(etat1 == "PKR")
    etat1 = "PKR (FullRange CC Gauge)";
  else if(etat1 == "PBR")
    etat1 = "PBR (FullRange BA Gauge)";
  else if(etat1 == "IMR")
    etat1 = "IMR (Pirani / High Pressure Gauge)";
  else if(etat1 == "CMR")
    etat1 = "CMR (Linear gauge)";
  else if(etat1 == "noSEn")
    etat1 = "noSEn (no SEnsor)";
  else if(etat1 == "noid")
    etat1 = "noid (no identifier)";

  if(etat2 == "TPR")
    etat2 = "TPR (Pirani Gauge or Pirani Capacitive gauge)";
  else if(etat2 == "IKR9")
    etat2 = "IKR9 (Cold Cathode Gauge 10-9)";
  else if(etat2 == "IKR11")
    etat2 = "IKR11 (Cold Cathode Gauge 10-11)";
  else if(etat2 == "PKR")
    etat2 = "PKR (FullRange CC Gauge)";
  else if(etat2 == "PBR")
    etat2 = "PBR (FullRange BA Gauge)";
  else if(etat2 == "IMR")
    etat2 = "IMR (Pirani / High Pressure Gauge)";
  else if(etat2 == "CMR")
    etat2 = "CMR (Linear gauge)";
  else if(etat2 == "noSEn")
    etat2 = "noSEn (no SEnsor)";
  else if(etat2 == "noid")
    etat2 = "noid (no identifier)";

  QString phrase;
  phrase = "Jauge 1 : " + etat1 + " - Jauge 2 : " + etat2;

  return phrase; 
}



/////////////////////////////////////////////
// TPG261 Error Status
QString TPG300::errorstatus2(void)
{
  QString valeur_retour = "-1"; // par defaut, on met a -1

  if(port == NULL) // Il y a un probleme
    return valeur_retour;        

  // envoi de ERR
  send_rs232("ERR");

  // reception de ACK (06) ou NAK (15)
  QString message = receive_rs232();
  if(message.contains("\x06") == FALSE )
    return "-1";

  // envoi de <ENQ>
  send_rs232("\x05");

  // reception de la valeur
  QString valeur = receive_rs232();

  // on retire <CR> et <LF>
  valeur = valeur.replace("\x0D", ""); // on supprime les caracteres de fin
  valeur = valeur.replace("\x0A", "");

  if(valeur == "0000")
    valeur = "No error";
  else if(valeur == "1000")
    valeur = "Controller error (see display on the front panel)";
  else if(valeur == "0100")
    valeur = "Hardware not installed";
  else if(valeur == "0010")
    valeur = "Inadmissible parameter";
  else if(valeur == "0001")
    valeur = "Syntax error";

  return valeur; 
}


/////////////////////////////////////////////
// TPG261 Display Unit
QString TPG300::pressureunit(void)
{
  QString valeur_retour = "-1"; // par defaut, on met a -1

  if(port == NULL) // Il y a un probleme
    return valeur_retour;        

  // envoi de UNI
  send_rs232("UNI");

  // reception de ACK (06) ou NAK (15)
  QString message = receive_rs232();
  if(message.contains("\x06") == FALSE )
    return "-1";

  // envoi de <ENQ>
  send_rs232("\x05");

  // reception de la valeur
  QString valeur = receive_rs232();

  // on retire <CR> et <LF>
  valeur = valeur.replace("\x0D", ""); // on supprime les caracteres de fin
  valeur = valeur.replace("\x0A", "");

  if(valeur == "0")
    valeur = "mbar / bar";
  else if(valeur == "1")
    valeur = "Torr";
  else if(valeur == "2")
    valeur = "Pascal";

  return valeur; 
}


/////////////////////////////////////////////
// TPG300 Sensor On/Off
QString TPG300::sensoronoff2(void)
{
  QString valeur_retour = "-1"; // par defaut, on met a -1

  if(port == NULL) // Il y a un probleme
    return valeur_retour;        

  // envoi de SEN
  send_rs232("SEN");

  // reception de ACK (06) ou NAK (15)
  QString message = receive_rs232();
  if(message.contains("\x06") == FALSE )
    return "-1";

  // envoi de <ENQ>
  send_rs232("\x05");

  // reception de la valeur
  QString valeur = receive_rs232();

  // on retire <CR> et <LF>
  valeur = valeur.replace("\x0D", ""); // on supprime les caracteres de fin
  valeur = valeur.replace("\x0A", "");

  // on cherche les etats
  QString etat1;
  QString etat2;

  if(QString::QString(valeur.at(0)) == "0")
    etat1 = "Gauge cannot be turned on/off";
  else if(QString::QString(valeur.at(0)) == "1")
    etat1 = "Gauge turned off";
  else if(QString::QString(valeur.at(0)) == "2")
    etat1 = "Gauge turned on";

  if(QString::QString(valeur.at(2)) == "0")
    etat2 = "Gauge cannot be turned on/off";
  else if(QString::QString(valeur.at(2)) == "1")
    etat2 = "Gauge turned off";
  else if(QString::QString(valeur.at(2)) == "2")
    etat2 = "Gauge turned on";


  QString phrase;
  phrase = "Jauge 1 : " + etat1 + " - Jauge 2 : " + etat2;

  return phrase; 
}
