#include "tpg300.h"

#include "send_receive.cpp" // Fonctions pour envoyer et recevoir
#include "fonctions_dialogues.cpp" // Fonctions de dialogue avec le TPG300

TPG300::TPG300(QWidget *parent) : QMainWindow(parent)
{
  ui.setupUi(this); // chargement de l'interface graphique

  port = NULL; // initialisation du port serie

  // creation du thread qui met a jour les valeurs
  thread.pt = this; // on donne le pointeur vers TPG300
  thread.start();

}


/////////////////////////////////////////////
// Configuration de la connexion RS232
/////////////////////////////////////////////
void TPG300::on_pushButton_1_1_clicked()
{
  // on affiche la fenetre
  fenetre_rs232.show();
}

/////////////////////////////////////////////
// Configuration de PARAMETRES
/////////////////////////////////////////////
void TPG300::on_pushButton_1_2_clicked()
{
  // on affiche la fenetre
  fenetre_parametres.show();
}

/////////////////////////////////////////////
// Connexion a l'appareil
/////////////////////////////////////////////
void TPG300::on_pushButton_1_3_clicked()
{

  // on efface le moniteur
  ui.textEdit_2_1->clear();


  // affiche sur le Moniteur que l'on a appuye sur le bouton connexion
  affichage_moniteur("Ouverture du port de communication");

  int erreur;
  // on configure le port de communication
  erreur = fenetre_rs232.connexion(port); // permet de se connecter a l'appareil

  if(erreur == -1)
  {
    affichage_moniteur("==> Erreur de connexion");
    thread.etat = 0;
    return;
  }
  else
  {
    port = (QextSerialPort *) erreur;
  }

  ui.lineEdit_1_8->setText("0"); // nombre de cycles de mesures
  nb_cycles = 0; // initialisation a 0

  QDateTime date = QDateTime::currentDateTime();
  date_init = date;

  ui.lineEdit_1_5->setText(date.toString( "dd/MM/yyyy") ); // Date de dpart
  ui.lineEdit_1_6->setText(date.toString( "HH:mm:ss") ); // Heure de dpart
  nom_file = "data/data_TPG261_" + date.toString( "yyyy-MM-dd_HH-mm-ss") + ".txt";
  ui.textEdit_1_1->insertPlainText( "./" + nom_file + "\n" ); // Nom du fichier d'enregistrement
  ui.textEdit_1_1->insertPlainText( "./data/data_TPG261_current.txt" ); // Nom du fichier d'enregistrement
  ui.lineEdit_1_7->setText( date.toString( "dd/MM/yyyy - HH:mm:ss") );

  // On complte le fichier de mesures
  QFile file;
  file.setFileName("data/data_TPG261_" + date.toString( "yyyy-MM-dd_HH-mm-ss") + ".txt");
  file.open(QIODevice::Append | QIODevice::Text );
  QTextStream out(&file);

  affichage_moniteur("Date et heure de dpart ==> " + date.toString( "dd/MM/yyyy - HH:mm:ss") );
  out << "Date et heure de dpart : " << date.toString( "dd/MM/yyyy - HH:mm:ss") << endl;

  QString programm_number = programmnumber();
  affichage_moniteur("Programm number ==> " + programm_number);
  out << "Programm number : " << programm_number << endl;

  QString error_status = errorstatus2();
  affichage_moniteur("Error Status ==> " + error_status);
  out << "Error Status : " << error_status << endl;

  QString display_unit = pressureunit();
  affichage_moniteur("Display Unit ==> " + display_unit);
  out << "Display Unit : " << display_unit << endl;

  QString sensor_onoff = sensoronoff2();
  affichage_moniteur("Sensor On/Off ==> " + sensor_onoff);
  out << "Sensor On/Off : " << sensor_onoff << endl;

  QString slot_ids = gaugeidentification();
  affichage_moniteur("Slot ID's ==> " + slot_ids);
  out << "Jauge identification : " << slot_ids << endl;

  QString get_pressa1 = pressuremeasurement("1");
  ui.lineEdit_1_1->setText(get_pressa1 ); 

  QString get_pressb1 = pressuremeasurement("2");
  ui.lineEdit_1_3->setText(get_pressb1 ); 

  out << endl;
  out << endl;

  out << "Date et heure de la mesure" << "\x09" << "Temps coul (s)" << "\x09" << "Pressure measuring 1" << "\x09" << "Pressure measuring 2" << endl;
  out << date.toString( "dd/MM/yyyy HH:mm:ss") << "\x09" << "0" << "\x09" << get_pressa1 << "\x09" << get_pressb1 << endl;
  
  file.close();


  // on enregistre les donnees dans le fichier courant
  // On complte le fichier de mesures
  QFile file_current;
  file.setFileName("data/data_TPG261_current.txt");
  if( file.exists() )
    file.remove();
  file.open(QIODevice::Append | QIODevice::Text );
  QTextStream out_current(&file);

  out_current << "Date et heure de la mesure" << "\x09" << ":" << "\x09" << date.toString( "dd/MM/yyyy HH:mm:ss") << endl;
  out_current << "Pressure measuring circuit 1" << "\x09" << ":" << "\x09" << get_pressa1 << endl;
  out_current << "Pressure measuring circuit 2" << "\x09" << ":" << "\x09" << get_pressb1 ;


  file_current.close();

  thread.etat = 1; // demarrage des mesures du thread

}



/////////////////////////////////////////////
// Affichage sur le moniteur
void TPG300::affichage_moniteur(QString la_commande)
{
  ui.textEdit_2_1->insertPlainText( la_commande.toLatin1() + "\n" ); 
}


/////////////////////////////////////////////
// Mesure des pressions
/////////////////////////////////////////////
void TPG300::mesure(void)
{

  nb_cycles++; // ajout d'un cycle
  ui.lineEdit_1_8->setText(QString::number(nb_cycles)); // nombre de cycles de mesures

  QDateTime date = QDateTime::currentDateTime();
  int temps_ecoule = date_init.secsTo(date);

  // on fait les mesures de pression
  QString get_pressa1 = pressuremeasurement("1");
  QString get_pressb1 = pressuremeasurement("2");

  // on affiche les resultats
  ui.lineEdit_1_1->setText(get_pressa1 ); 
  ui.lineEdit_1_3->setText(get_pressb1 ); 

  // on affiche l'heure
  ui.lineEdit_1_7->setText( date.toString( "dd/MM/yyyy - HH:mm:ss") );

  // On complte le fichier de mesures
  QFile file;
  file.setFileName(nom_file);
  file.open(QIODevice::Append | QIODevice::Text );
  QTextStream out(&file);
  out << date.toString( "dd/MM/yyyy HH:mm:ss") << "\x09" << temps_ecoule << "\x09" << get_pressa1 << "\x09" << get_pressb1 << endl;
  file.close();

  // on enregistre les donnees dans le fichier courant
  QFile file_current;
  file.setFileName("data/data_TPG261_current.txt");
  if( file.exists() )
    file.remove();
  file.open(QIODevice::Append | QIODevice::Text );
  QTextStream out_current(&file);
  out_current << "Date et heure de la mesure" << "\x09" << ":" << "\x09" << date.toString( "dd/MM/yyyy HH:mm:ss") << endl;
  out_current << "Pressure measuring 1" << "\x09" << ":" << "\x09" << get_pressa1 << endl;
  out_current << "Pressure measuring 2" << "\x09" << ":" << "\x09" << get_pressb1 ;

  file_current.close();

}
